pub struct ProcessedDeployProto {
pub deploy: Option<DeployDataProto>,
pub cost: Option<PCost>,
pub deploy_log: Vec<EventProto>,
pub errored: bool,
pub system_deploy_error: String,
}Fields
deploy: Option<DeployDataProto>cost: Option<PCost>deploy_log: Vec<EventProto>the new terms and comm. rule reductions from this deploy
errored: booltrue if deploy encountered a user error
system_deploy_error: StringTrait Implementations
Sourceimpl Clone for ProcessedDeployProto
impl Clone for ProcessedDeployProto
Sourcefn clone(&self) -> ProcessedDeployProto
fn clone(&self) -> ProcessedDeployProto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessedDeployProto
impl Debug for ProcessedDeployProto
Sourceimpl Default for ProcessedDeployProto
impl Default for ProcessedDeployProto
Sourceimpl<'de> Deserialize<'de> for ProcessedDeployProto
impl<'de> Deserialize<'de> for ProcessedDeployProto
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for ProcessedDeployProto
impl Message for ProcessedDeployProto
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProcessedDeployProto
impl PartialEq for ProcessedDeployProto
Sourcefn eq(&self, other: &ProcessedDeployProto) -> bool
fn eq(&self, other: &ProcessedDeployProto) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProcessedDeployProto
impl Serialize for ProcessedDeployProto
impl StructuralPartialEq for ProcessedDeployProto